#!/bin/bash
#
# Copyright (C) 2004 Mr_Moustache, Lille, FRANCE
#
#
# Ce script est bas sur un slackbuild de LiNuCe, Marseille, FRANCE
#
# Ce programme est un logiciel libre. Vous pouvez le redistribuer
# et/ou le modifier sous les termes de la license GNU GPL telle
# qu'elle est publie par la FSF (Free Software Foundation), en
# utilisant la version 2 de cette licence ou, selon votre choix,
# toute autre version plus rcente.

if [ $UID -eq 0 ]; then
    echo "Do not execute this shell script with ROOT rights !"
    exit 1
fi

set -e -x

### SlackBuild configuration ###
source $PWD/build.conf
### SlackBuild configuration END ###

cwd=$PWD

# Cleanup temporary files
if [ ! -d "$tmp" ]; then
    mkdir -m 755 -p $tmp
else
    rm -rf $tmp/$name-$version
    rm -rf $pkg
fi

# Uncompress sources files
tar xjf $name-$version.tar.bz2 -C $tmp \
|| tar xzf $name-$version.tar.gz -C $tmp

cd $tmp/$name-$version

### Compilation ###
export LANG=C
export LC_ALL=C

# Configuration
./configure \
    --prefix=/usr

# Compilation
make

# Installation
mkdir -m 755 -p $pkg
make DESTDIR=$pkg install
### Fin de Compilation ###

### Documentation ###
docs="AUTHORS ChangeLog COPYING NEWS"
mkdir -m 755 -p $pkg/usr/doc/$name-$version
install -m 644 $docs $pkg/usr/doc/$name-$version/
# Man
find $pkg/usr/man/de/man1 -name "*.1" -exec gzip -9 {} \;

mkdir -m 755 $pkg/install
install -m 644 $cwd/slack-desc $pkg/install/slack-desc

### Permissions/Stripping ###
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

cd $tmp
rm -rf $name-$version
echo "Temporary installation ended."
echo "You can launch the pack.sh script with ROOT rights."
exit 0

